==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/VolumeClaimDataSourceRefArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimDataSourceRefArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VolumeClaimDataSourceRef properties
 * @property apiGroup APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
 * @property kind Kind is the type of resource being referenced
 * @property name Name is the name of resource being referenced
 */
public data class VolumeClaimDataSourceRefArgs(
    public val apiGroup: Output<String>? = null,
    public val kind: Output<String>,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimDataSourceRefArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimDataSourceRefArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimDataSourceRefArgs.builder()
            .apiGroup(apiGroup?.applyValue({ args0 -> args0 }))
            .kind(kind.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VolumeClaimDataSourceRefArgs].
 */
@PulumiTagMarker
public class VolumeClaimDataSourceRefArgsBuilder internal constructor() {
    private var apiGroup: Output<String>? = null

    private var kind: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
     */
    @JvmName("xvylpspipvuecktq")
    public suspend fun apiGroup(`value`: Output<String>) {
        this.apiGroup = value
    }

    /**
     * @param value Kind is the type of resource being referenced
     */
    @JvmName("rnwukfrwjjtjteet")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Name is the name of resource being referenced
     */
    @JvmName("nblxodgoqftrlbur")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
     */
    @JvmName("mjyrcjifootwtogd")
    public suspend fun apiGroup(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiGroup = mapped
    }

    /**
     * @param value Kind is the type of resource being referenced
     */
    @JvmName("haacqexorifvmiih")
    public suspend fun kind(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name is the name of resource being referenced
     */
    @JvmName("fjypdvshxwqosdmc")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): VolumeClaimDataSourceRefArgs = VolumeClaimDataSourceRefArgs(
        apiGroup = apiGroup,
        kind = kind ?: throw PulumiNullFieldException("kind"),
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/VolumeClaimDataSourceRefArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimDataSourceRefArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VolumeClaimDataSourceRef properties
 * @property apiGroup APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
 * @property kind Kind is the type of resource being referenced
 * @property name Name is the name of resource being referenced
 */
public data class VolumeClaimDataSourceRefArgs(
    public val apiGroup: Output<String>? = null,
    public val kind: Output<String>,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimDataSourceRefArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimDataSourceRefArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.VolumeClaimDataSourceRefArgs.builder()
            .apiGroup(apiGroup?.applyValue({ args0 -> args0 }))
            .kind(kind.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VolumeClaimDataSourceRefArgs].
 */
@PulumiTagMarker
public class VolumeClaimDataSourceRefArgsBuilder internal constructor() {
    private var apiGroup: Output<String>? = null

    private var kind: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
     */
    @JvmName("bicokmbpevpydnte")
    public suspend fun apiGroup(`value`: Output<String>) {
        this.apiGroup = value
    }

    /**
     * @param value Kind is the type of resource being referenced
     */
    @JvmName("toegmcunegnwnfey")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Name is the name of resource being referenced
     */
    @JvmName("btimjkknqxrnqtpj")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
     */
    @JvmName("lhmusvwsgjgxduyi")
    public suspend fun apiGroup(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiGroup = mapped
    }

    /**
     * @param value Kind is the type of resource being referenced
     */
    @JvmName("edhqlklwktlknoab")
    public suspend fun kind(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name is the name of resource being referenced
     */
    @JvmName("vlotindjwiqgcdgg")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): VolumeClaimDataSourceRefArgs = VolumeClaimDataSourceRefArgs(
        apiGroup = apiGroup,
        kind = kind ?: throw PulumiNullFieldException("kind"),
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
